@@ -39,22 +39,17 @@ func NewSQLLoaderForDirectory(store registry.Load, directory string) *DirectoryL
 func (d *DirectoryLoader) Populate() error {
 	log := logrus.WithField("dir", d.directory)
 
-	log.Info("Loading bundles")
+	log.Info("loading Bundles")
 	errs := make([]error, 0)
 	if err := filepath.Walk(d.directory, collectWalkErrs(d.LoadBundleWalkFunc, &errs)); err != nil {
 		errs = append(errs, err)
 	}
 
-	log.Info("Loading packages and entries")
+	log.Info("loading Packages and Entries")
 	if err := filepath.Walk(d.directory, collectWalkErrs(d.LoadPackagesWalkFunc, &errs)); err != nil {
 		errs = append(errs, err)
 	}
 
-	log.Info("Extracting provided API information")
-	if err := d.store.AddProvidedAPIs(); err != nil {
-		errs = append(errs, err)
-	}
-
 	return utilerrors.NewAggregate(errs)
 }
 
@@ -102,7 +97,6 @@ func (d *DirectoryLoader) LoadBundleWalkFunc(path string, f os.FileInfo, err err
 	csv := unstructured.Unstructured{}
 
 	if err = decoder.Decode(&csv); err != nil {
-		log.Infof("could not decode contents of file %s into csv: %s", path, err)
 		return nil
 	}
 
@@ -113,7 +107,7 @@ func (d *DirectoryLoader) LoadBundleWalkFunc(path string, f os.FileInfo, err err
 	log.Info("found csv, loading bundle")
 
 	var errs []error
-	bundle, err := d.LoadBundle(csv.GetName(), filepath.Dir(path))
+	bundle, err := loadBundle(csv.GetName(), filepath.Dir(path))
 	if err != nil {
 		errs = append(errs, fmt.Errorf("error loading objs in directory: %s", err))
 	}
@@ -128,23 +122,72 @@ func (d *DirectoryLoader) LoadBundleWalkFunc(path string, f os.FileInfo, err err
 	}
 
 	if err := d.store.AddOperatorBundle(bundle); err != nil {
-		errs = append(errs, fmt.Errorf("error adding operator bundle %s: %s", bundle.Name, err))
+		version, _ := bundle.Version()
+		errs = append(errs, fmt.Errorf("error adding operator bundle %s/%s/%s: %s", csv.GetName(), version, bundle.BundleImage, err))
 	}
 
 	return utilerrors.NewAggregate(errs)
 }
 
-// LoadBundle takes the directory that a CSV is in and assumes the rest of the objects in that directory
+// LoadPackagesWalkFunc attempts to unmarshal the file at the given path into a PackageManifest resource.
+// If unmarshaling is successful, the PackageManifest is added to the loader's store.
+func (d *DirectoryLoader) LoadPackagesWalkFunc(path string, f os.FileInfo, err error) error {
+	if f == nil {
+		return fmt.Errorf("invalid file: %v", f)
+	}
+
+	log := logrus.WithFields(logrus.Fields{"dir": d.directory, "file": f.Name(), "load": "package"})
+	if f.IsDir() {
+		if strings.HasPrefix(f.Name(), ".") {
+			log.Info("skipping hidden directory")
+			return filepath.SkipDir
+		}
+		log.Info("directory")
+		return nil
+	}
+
+	if strings.HasPrefix(f.Name(), ".") {
+		log.Info("skipping hidden file")
+		return nil
+	}
+
+	fileReader, err := os.Open(path)
+	if err != nil {
+		return fmt.Errorf("unable to load package from file %s: %s", path, err)
+	}
+
+	decoder := yaml.NewYAMLOrJSONDecoder(fileReader, 30)
+	manifest := registry.PackageManifest{}
+	if err = decoder.Decode(&manifest); err != nil {
+		if err != nil {
+			return fmt.Errorf("could not decode contents of file %s into package: %s", path, err)
+		}
+
+	}
+	if manifest.PackageName == "" {
+		return nil
+	}
+
+	if err := d.store.AddPackageChannels(manifest); err != nil {
+		return fmt.Errorf("error loading package into db: %s", err)
+	}
+
+	return nil
+}
+
+// loadBundle takes the directory that a CSV is in and assumes the rest of the objects in that directory
 // are part of the bundle.
-func (d *DirectoryLoader) LoadBundle(csvName string, dir string) (*registry.Bundle, error) {
-	bundle := &registry.Bundle{}
-	log := logrus.WithFields(logrus.Fields{"dir": d.directory, "load": "bundle"})
+func loadBundle(csvName string, dir string) (*registry.Bundle, error) {
+	log := logrus.WithFields(logrus.Fields{"dir": dir, "load": "bundle", "name": csvName})
 	files, err := ioutil.ReadDir(dir)
 	if err != nil {
 		return nil, err
 	}
 
 	var errs []error
+	bundle := &registry.Bundle{
+		Name: csvName,
+	}
 	for _, f := range files {
 		log = log.WithField("file", f.Name())
 		if f.IsDir() {
@@ -184,46 +227,3 @@ func (d *DirectoryLoader) LoadBundle(csvName string, dir string) (*registry.Bund
 
 	return bundle, utilerrors.NewAggregate(errs)
 }
-
-// LoadPackagesWalkFunc attempts to unmarshal the file at the given path into a PackageManifest resource.
-// If unmarshaling is successful, the PackageManifest is added to the loader's store.
-func (d *DirectoryLoader) LoadPackagesWalkFunc(path string, f os.FileInfo, err error) error {
-	if f == nil {
-		return fmt.Errorf("invalid file: %v", f)
-	}
-
-	log := logrus.WithFields(logrus.Fields{"dir": d.directory, "file": f.Name(), "load": "package"})
-	if f.IsDir() {
-		if strings.HasPrefix(f.Name(), ".") {
-			log.Info("skipping hidden directory")
-			return filepath.SkipDir
-		}
-		log.Info("directory")
-		return nil
-	}
-
-	if strings.HasPrefix(f.Name(), ".") {
-		log.Info("skipping hidden file")
-		return nil
-	}
-
-	fileReader, err := os.Open(path)
-	if err != nil {
-		return fmt.Errorf("unable to load package from file %s: %s", path, err)
-	}
-
-	decoder := yaml.NewYAMLOrJSONDecoder(fileReader, 30)
-	manifest := registry.PackageManifest{}
-	if err = decoder.Decode(&manifest); err != nil {
-		return fmt.Errorf("could not decode contents of file %s into package: %s", path, err)
-	}
-	if manifest.PackageName == "" {
-		return nil
-	}
-
-	if err := d.store.AddPackageChannels(manifest); err != nil {
-		return fmt.Errorf("error loading package into db: %s", err)
-	}
-
-	return nil
-}
